==> libkdegames-25.04.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KDEGames6/KDEGames6Targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration ""
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.6.0.250400"
  IMPORTED_SONAME_NOCONFIG "libKDEGames6Private.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.6.0.250400" )

# Import target "KDEGames6" for configuration ""
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKDEGames6.so.6.0.250400"
  IMPORTED_SONAME_NOCONFIG "libKDEGames6.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib/libKDEGames6.so.6.0.250400" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libkdegames-25.08.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KDEGames6/KDEGames6Targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KDEGames6Private" for configuration ""
set_property(TARGET KDEGames6Private APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDEGames6Private PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::DNSSD;KF6::I18n;KF6::Archive;KF6::CoreAddons;KF6::XmlGui"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.6.0.250800"
  IMPORTED_SONAME_NOCONFIG "libKDEGames6Private.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6Private )
list(APPEND _cmake_import_check_files_for_KDEGames6Private "${_IMPORT_PREFIX}/lib/libKDEGames6Private.so.6.0.250800" )

# Import target "KDEGames6" for configuration ""
set_property(TARGET KDEGames6 APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KDEGames6 PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF6::NewStuffWidgets;KF6::IconThemes;KF6::I18n;KF6::XmlGui;KF6::GuiAddons;KF6::Completion;KF6::ColorScheme;Qt6::Xml;Qt6::Svg;Qt6::Quick"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKDEGames6.so.6.0.250800"
  IMPORTED_SONAME_NOCONFIG "libKDEGames6.so.6"
  )

list(APPEND _cmake_import_check_targets KDEGames6 )
list(APPEND _cmake_import_check_files_for_KDEGames6 "${_IMPORT_PREFIX}/lib/libKDEGames6.so.6.0.250800" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
